==> unknown-horizons_2013.2+ds1.orig.tar.xz: unknown-horizons/content/atlas.sql <==
CREATE TABLE atlas('atlas_id' INTEGER NOT NULL PRIMARY KEY, 'atlas_path' TEXT NOT NULL);
INSERT INTO atlas VALUES(0, 'content/gfx/atlas/000.png');
INSERT INTO atlas VALUES(1, 'content/gfx/atlas/001.png');
INSERT INTO atlas VALUES(2, 'content/gfx/atlas/002.png');
INSERT INTO atlas VALUES(3, 'content/gfx/atlas/003.png');
INSERT INTO atlas VALUES(4, 'content/gfx/atlas/004.png');
INSERT INTO atlas VALUES(5, 'content/gfx/atlas/005.png');
INSERT INTO atlas VALUES(6, 'content/gfx/atlas/006.png');
INSERT INTO atlas VALUES(7, 'content/gfx/atlas/007.png');
INSERT INTO atlas VALUES(8, 'content/gfx/atlas/008.png');
INSERT INTO atlas VALUES(9, 'content/gfx/atlas/009.png');
INSERT INTO atlas VALUES(10, 'content/gfx/atlas/010.png');
INSERT INTO atlas VALUES(11, 'content/gfx/atlas/011.png');
INSERT INTO atlas VALUES(12, 'content/gfx/atlas/012.png');
INSERT INTO atlas VALUES(13, 'content/gfx/atlas/013.png');
INSERT INTO atlas VALUES(14, 'content/gfx/atlas/014.png');
INSERT INTO atlas VALUES(15, 'content/gfx/atlas/015.png');
INSERT INTO atlas VALUES(16, 'content/gfx/atlas/016.png');
INSERT INTO atlas VALUES(17, 'content/gfx/atlas/017.png');
INSERT INTO atlas VALUES(18, 'content/gfx/atlas/018.png');
INSERT INTO atlas VALUES(19, 'content/gfx/atlas/019.png');
INSERT INTO atlas VALUES(20, 'content/gfx/atlas/020.png');
INSERT INTO atlas VALUES(21, 'content/gfx/atlas/021.png');
INSERT INTO atlas VALUES(22, 'content/gfx/atlas/022.png');
INSERT INTO atlas VALUES(23, 'content/gfx/atlas/023.png');
INSERT INTO atlas VALUES(24, 'content/gfx/atlas/024.png');
INSERT INTO atlas VALUES(25, 'content/gfx/atlas/025.png');
INSERT INTO atlas VALUES(26, 'content/gfx/atlas/026.png');
INSERT INTO atlas VALUES(27, 'content/gfx/atlas/027.png');
INSERT INTO atlas VALUES(28, 'content/gfx/atlas/028.png');
INSERT INTO atlas VALUES(29, 'content/gfx/atlas/029.png');
INSERT INTO atlas VALUES(30, 'content/gfx/atlas/030.png');
INSERT INTO atlas VALUES(31, 'content/gfx/atlas/031.png');
INSERT INTO atlas VALUES(32, 'content/gfx/atlas/032.png');
INSERT INTO atlas VALUES(33, 'content/gfx/atlas/033.png');
INSERT INTO atlas VALUES(34, 'content/gfx/atlas/034.png');
INSERT INTO atlas VALUES(35, 'content/gfx/atlas/035.png');
INSERT INTO atlas VALUES(36, 'content/gfx/atlas/036.png');
INSERT INTO atlas VALUES(37, 'content/gfx/atlas/037.png');
INSERT INTO atlas VALUES(38, 'content/gfx/atlas/038.png');
INSERT INTO atlas VALUES(39, 'content/gfx/atlas/039.png');
INSERT INTO atlas VALUES(40, 'content/gfx/atlas/040.png');
INSERT INTO atlas VALUES(41, 'content/gfx/atlas/041.png');
INSERT INTO atlas VALUES(42, 'content/gfx/atlas/042.png');
INSERT INTO atlas VALUES(43, 'content/gfx/atlas/043.png');
INSERT INTO atlas VALUES(44, 'content/gfx/atlas/044.png');
INSERT INTO atlas VALUES(45, 'content/gfx/atlas/045.png');
INSERT INTO atlas VALUES(46, 'content/gfx/atlas/046.png');
INSERT INTO atlas VALUES(47, 'content/gfx/atlas/047.png');
INSERT INTO atlas VALUES(48, 'content/gfx/atlas/048.png');
INSERT INTO atlas VALUES(49, 'content/gfx/atlas/049.png');
INSERT INTO atlas VALUES(50, 'content/gfx/atlas/050.png');
INSERT INTO atlas VALUES(51, 'content/gfx/atlas/051.png');
INSERT INTO atlas VALUES(52, 'content/gfx/atlas/052.png');
INSERT INTO atlas VALUES(53, 'content/gfx/atlas/053.png');
INSERT INTO atlas VALUES(54, 'content/gfx/atlas/054.png');
INSERT INTO atlas VALUES(55, 'content/gfx/atlas/055.png');
INSERT INTO atlas VALUES(56, 'content/gfx/atlas/056.png');
INSERT INTO atlas VALUES(57, 'content/gfx/atlas/057.png');
INSERT INTO atlas VALUES(58, 'content/gfx/atlas/058.png');
INSERT INTO atlas VALUES(59, 'content/gfx/atlas/059.png');
INSERT INTO atlas VALUES(60, 'content/gfx/atlas/060.png');
INSERT INTO atlas VALUES(61, 'content/gfx/atlas/061.png');
INSERT INTO atlas VALUES(62, 'content/gfx/atlas/062.png');
INSERT INTO atlas VALUES(63, 'content/gfx/atlas/063.png');
INSERT INTO atlas VALUES(64, 'content/gfx/atlas/064.png');
INSERT INTO atlas VALUES(65, 'content/gfx/atlas/065.png');
INSERT INTO atlas VALUES(66, 'content/gfx/atlas/066.png');
INSERT INTO atlas VALUES(67, 'content/gfx/atlas/067.png');
INSERT INTO atlas VALUES(68, 'content/gfx/atlas/068.png');
INSERT INTO atlas VALUES(69, 'content/gfx/atlas/069.png');
INSERT INTO atlas VALUES(70, 'content/gfx/atlas/070.png');
INSERT INTO atlas VALUES(71, 'content/gfx/atlas/071.png');
INSERT INTO atlas VALUES(72, 'content/gfx/atlas/072.png');
INSERT INTO atlas VALUES(73, 'content/gfx/atlas/073.png');
INSERT INTO atlas VALUES(74, 'content/gfx/atlas/074.png');
INSERT INTO atlas VALUES(75, 'content/gfx/atlas/075.png');
INSERT INTO atlas VALUES(76, 'content/gfx/atlas/076.png');
INSERT INTO atlas VALUES(77, 'content/gfx/atlas/077.png');
INSERT INTO atlas VALUES(78, 'content/gfx/atlas/078.png');
INSERT INTO atlas VALUES(79, 'content/gfx/atlas/079.png');
INSERT INTO atlas VALUES(80, 'content/gfx/atlas/080.png');
INSERT INTO atlas VALUES(81, 'content/gfx/atlas/081.png');
INSERT INTO atlas VALUES(82, 'content/gfx/atlas/082.png');
INSERT INTO atlas VALUES(83, 'content/gfx/atlas/083.png');
INSERT INTO atlas VALUES(84, 'content/gfx/atlas/084.png');
INSERT INTO atlas VALUES(85, 'content/gfx/atlas/085.png');
INSERT INTO atlas VALUES(86, 'content/gfx/atlas/086.png');
INSERT INTO atlas VALUES(87, 'content/gfx/atlas/087.png');
INSERT INTO atlas VALUES(88, 'content/gfx/atlas/088.png');
INSERT INTO atlas VALUES(89, 'content/gfx/atlas/089.png');
INSERT INTO atlas VALUES(90, 'content/gfx/atlas/090.png');
INSERT INTO atlas VALUES(91, 'content/gfx/atlas/091.png');
INSERT INTO atlas VALUES(92, 'content/gfx/atlas/092.png');
INSERT INTO atlas VALUES(93, 'content/gfx/atlas/093.png');
INSERT INTO atlas VALUES(94, 'content/gfx/atlas/094.png');
INSERT INTO atlas VALUES(95, 'content/gfx/atlas/095.png');
INSERT INTO atlas VALUES(96, 'content/gfx/atlas/096.png');
INSERT INTO atlas VALUES(97, 'content/gfx/atlas/097.png');
INSERT INTO atlas VALUES(98, 'content/gfx/atlas/098.png');
INSERT INTO atlas VALUES(99, 'content/gfx/atlas/099.png');
INSERT INTO atlas VALUES(100, 'content/gfx/atlas/100.png');
INSERT INTO atlas VALUES(101, 'content/gfx/atlas/101.png');
INSERT INTO atlas VALUES(102, 'content/gfx/atlas/102.png');
INSERT INTO atlas VALUES(103, 'content/gfx/atlas/103.png');
INSERT INTO atlas VALUES(104, 'content/gfx/atlas/104.png');
INSERT INTO atlas VALUES(105, 'content/gfx/atlas/105.png');
INSERT INTO atlas VALUES(106, 'content/gfx/atlas/106.png');
INSERT INTO atlas VALUES(107, 'content/gfx/atlas/107.png');
INSERT INTO atlas VALUES(108, 'content/gfx/atlas/108.png');

==> unknown-horizons_2013.3+ds1.orig.tar.xz: unknown-horizons/content/atlas.sql <==
CREATE TABLE atlas('atlas_id' INTEGER NOT NULL PRIMARY KEY, 'atlas_path' TEXT NOT NULL);
INSERT INTO atlas VALUES(0, 'content/gfx/atlas/000.png');
INSERT INTO atlas VALUES(1, 'content/gfx/atlas/001.png');
INSERT INTO atlas VALUES(2, 'content/gfx/atlas/002.png');
INSERT INTO atlas VALUES(3, 'content/gfx/atlas/003.png');
INSERT INTO atlas VALUES(4, 'content/gfx/atlas/004.png');
INSERT INTO atlas VALUES(5, 'content/gfx/atlas/005.png');
INSERT INTO atlas VALUES(6, 'content/gfx/atlas/006.png');
INSERT INTO atlas VALUES(7, 'content/gfx/atlas/007.png');
INSERT INTO atlas VALUES(8, 'content/gfx/atlas/008.png');
INSERT INTO atlas VALUES(9, 'content/gfx/atlas/009.png');
INSERT INTO atlas VALUES(10, 'content/gfx/atlas/010.png');
INSERT INTO atlas VALUES(11, 'content/gfx/atlas/011.png');
INSERT INTO atlas VALUES(12, 'content/gfx/atlas/012.png');
INSERT INTO atlas VALUES(13, 'content/gfx/atlas/013.png');
INSERT INTO atlas VALUES(14, 'content/gfx/atlas/014.png');
INSERT INTO atlas VALUES(15, 'content/gfx/atlas/015.png');
INSERT INTO atlas VALUES(16, 'content/gfx/atlas/016.png');
INSERT INTO atlas VALUES(17, 'content/gfx/atlas/017.png');
INSERT INTO atlas VALUES(18, 'content/gfx/atlas/018.png');
INSERT INTO atlas VALUES(19, 'content/gfx/atlas/019.png');
INSERT INTO atlas VALUES(20, 'content/gfx/atlas/020.png');
INSERT INTO atlas VALUES(21, 'content/gfx/atlas/021.png');
INSERT INTO atlas VALUES(22, 'content/gfx/atlas/022.png');
INSERT INTO atlas VALUES(23, 'content/gfx/atlas/023.png');
INSERT INTO atlas VALUES(24, 'content/gfx/atlas/024.png');
INSERT INTO atlas VALUES(25, 'content/gfx/atlas/025.png');
INSERT INTO atlas VALUES(26, 'content/gfx/atlas/026.png');
INSERT INTO atlas VALUES(27, 'content/gfx/atlas/027.png');
INSERT INTO atlas VALUES(28, 'content/gfx/atlas/028.png');
INSERT INTO atlas VALUES(29, 'content/gfx/atlas/029.png');
INSERT INTO atlas VALUES(30, 'content/gfx/atlas/030.png');
INSERT INTO atlas VALUES(31, 'content/gfx/atlas/031.png');
INSERT INTO atlas VALUES(32, 'content/gfx/atlas/032.png');
INSERT INTO atlas VALUES(33, 'content/gfx/atlas/033.png');
INSERT INTO atlas VALUES(34, 'content/gfx/atlas/034.png');
INSERT INTO atlas VALUES(35, 'content/gfx/atlas/035.png');
INSERT INTO atlas VALUES(36, 'content/gfx/atlas/036.png');
INSERT INTO atlas VALUES(37, 'content/gfx/atlas/037.png');
INSERT INTO atlas VALUES(38, 'content/gfx/atlas/038.png');
INSERT INTO atlas VALUES(39, 'content/gfx/atlas/039.png');
INSERT INTO atlas VALUES(40, 'content/gfx/atlas/040.png');
INSERT INTO atlas VALUES(41, 'content/gfx/atlas/041.png');
INSERT INTO atlas VALUES(42, 'content/gfx/atlas/042.png');
INSERT INTO atlas VALUES(43, 'content/gfx/atlas/043.png');
INSERT INTO atlas VALUES(44, 'content/gfx/atlas/044.png');
INSERT INTO atlas VALUES(45, 'content/gfx/atlas/045.png');
INSERT INTO atlas VALUES(46, 'content/gfx/atlas/046.png');
INSERT INTO atlas VALUES(47, 'content/gfx/atlas/047.png');
INSERT INTO atlas VALUES(48, 'content/gfx/atlas/048.png');
INSERT INTO atlas VALUES(49, 'content/gfx/atlas/049.png');
INSERT INTO atlas VALUES(50, 'content/gfx/atlas/050.png');
INSERT INTO atlas VALUES(51, 'content/gfx/atlas/051.png');
INSERT INTO atlas VALUES(52, 'content/gfx/atlas/052.png');
INSERT INTO atlas VALUES(53, 'content/gfx/atlas/053.png');
INSERT INTO atlas VALUES(54, 'content/gfx/atlas/054.png');
INSERT INTO atlas VALUES(55, 'content/gfx/atlas/055.png');
INSERT INTO atlas VALUES(56, 'content/gfx/atlas/056.png');
INSERT INTO atlas VALUES(57, 'content/gfx/atlas/057.png');
INSERT INTO atlas VALUES(58, 'content/gfx/atlas/058.png');
INSERT INTO atlas VALUES(59, 'content/gfx/atlas/059.png');
INSERT INTO atlas VALUES(60, 'content/gfx/atlas/060.png');
INSERT INTO atlas VALUES(61, 'content/gfx/atlas/061.png');
INSERT INTO atlas VALUES(62, 'content/gfx/atlas/062.png');
INSERT INTO atlas VALUES(63, 'content/gfx/atlas/063.png');
INSERT INTO atlas VALUES(64, 'content/gfx/atlas/064.png');
INSERT INTO atlas VALUES(65, 'content/gfx/atlas/065.png');
INSERT INTO atlas VALUES(66, 'content/gfx/atlas/066.png');
INSERT INTO atlas VALUES(67, 'content/gfx/atlas/067.png');
INSERT INTO atlas VALUES(68, 'content/gfx/atlas/068.png');
INSERT INTO atlas VALUES(69, 'content/gfx/atlas/069.png');
INSERT INTO atlas VALUES(70, 'content/gfx/atlas/070.png');
INSERT INTO atlas VALUES(71, 'content/gfx/atlas/071.png');
INSERT INTO atlas VALUES(72, 'content/gfx/atlas/072.png');
INSERT INTO atlas VALUES(73, 'content/gfx/atlas/073.png');
INSERT INTO atlas VALUES(74, 'content/gfx/atlas/074.png');
INSERT INTO atlas VALUES(75, 'content/gfx/atlas/075.png');
INSERT INTO atlas VALUES(76, 'content/gfx/atlas/076.png');
INSERT INTO atlas VALUES(77, 'content/gfx/atlas/077.png');
INSERT INTO atlas VALUES(78, 'content/gfx/atlas/078.png');
INSERT INTO atlas VALUES(79, 'content/gfx/atlas/079.png');
INSERT INTO atlas VALUES(80, 'content/gfx/atlas/080.png');
INSERT INTO atlas VALUES(81, 'content/gfx/atlas/081.png');
INSERT INTO atlas VALUES(82, 'content/gfx/atlas/082.png');
INSERT INTO atlas VALUES(83, 'content/gfx/atlas/083.png');
INSERT INTO atlas VALUES(84, 'content/gfx/atlas/084.png');
INSERT INTO atlas VALUES(85, 'content/gfx/atlas/085.png');
INSERT INTO atlas VALUES(86, 'content/gfx/atlas/086.png');
INSERT INTO atlas VALUES(87, 'content/gfx/atlas/087.png');
INSERT INTO atlas VALUES(88, 'content/gfx/atlas/088.png');
INSERT INTO atlas VALUES(89, 'content/gfx/atlas/089.png');
INSERT INTO atlas VALUES(90, 'content/gfx/atlas/090.png');
INSERT INTO atlas VALUES(91, 'content/gfx/atlas/091.png');
INSERT INTO atlas VALUES(92, 'content/gfx/atlas/092.png');
INSERT INTO atlas VALUES(93, 'content/gfx/atlas/093.png');
INSERT INTO atlas VALUES(94, 'content/gfx/atlas/094.png');
INSERT INTO atlas VALUES(95, 'content/gfx/atlas/095.png');
INSERT INTO atlas VALUES(96, 'content/gfx/atlas/096.png');
INSERT INTO atlas VALUES(97, 'content/gfx/atlas/097.png');
INSERT INTO atlas VALUES(98, 'content/gfx/atlas/098.png');
INSERT INTO atlas VALUES(99, 'content/gfx/atlas/099.png');
INSERT INTO atlas VALUES(100, 'content/gfx/atlas/100.png');
INSERT INTO atlas VALUES(101, 'content/gfx/atlas/101.png');
INSERT INTO atlas VALUES(102, 'content/gfx/atlas/102.png');
INSERT INTO atlas VALUES(103, 'content/gfx/atlas/103.png');
INSERT INTO atlas VALUES(104, 'content/gfx/atlas/104.png');
INSERT INTO atlas VALUES(105, 'content/gfx/atlas/105.png');
INSERT INTO atlas VALUES(106, 'content/gfx/atlas/106.png');
INSERT INTO atlas VALUES(107, 'content/gfx/atlas/107.png');
INSERT INTO atlas VALUES(108, 'content/gfx/atlas/108.png');
INSERT INTO atlas VALUES(109, 'content/gfx/atlas/109.png');
INSERT INTO atlas VALUES(110, 'content/gfx/atlas/110.png');
INSERT INTO atlas VALUES(111, 'content/gfx/atlas/111.png');
INSERT INTO atlas VALUES(112, 'content/gfx/atlas/112.png');
